@@ -64,6 +64,7 @@
 #define MAXSTACK  MAX_BOARD * MAX_BOARD
 #define MAXCHAIN  160
 
+#define HASH_RANDOM_SEED 12345
 
 /* ================================================================ *
  *                         One-dimensional board                    *
@@ -182,7 +183,7 @@ extern int          move_history_pointer;
 extern float        komi;
 extern int          movenum;      /* movenumber - used for debug output */
 		    
-extern char         shadow[BOARDMAX];      /* reading tree shadow */
+extern signed char  shadow[BOARDMAX];      /* reading tree shadow */
 
 extern int chinese_rules;
 extern int allow_suicide;
@@ -289,8 +290,7 @@ int neighbor_of_string(int pos, int str);
 int has_neighbor(int pos, int color);
 int same_string(int str1, int str2);
 int adjacent_strings(int str1, int str2);
-void mark_string(int str, char mx[BOARDMAX], char mark);
-void signed_mark_string(int str, signed char mx[BOARDMAX], signed char mark);
+void mark_string(int str, signed char mx[BOARDMAX], signed char mark);
 int are_neighbors(int pos1, int pos2);
 
 /* Count and/or find liberties at (pos). */
@@ -385,13 +385,13 @@ const char *color_to_string(int color);
 const char *location_to_string(int pos);
 void location_to_buffer(int pos, char *buf);
 
-int string_to_location(int boardsize, const char *str, int *m, int *n);
+int string_to_location(int boardsize, const char *str);
 
 int is_hoshi_point(int m, int n);
 void draw_letter_coordinates(FILE *outfile);
 void simple_showboard(FILE *outfile);
 
-void mark_goal_in_sgf(char goal[BOARDMAX]);
+void mark_goal_in_sgf(signed char goal[BOARDMAX]);
 
 /* ================================================================ */
 /*                         assertions                               */
