@@ -41,12 +41,12 @@ int          move_history_color[MAX_MOVE_HISTORY];
 int          move_history_pos[MAX_MOVE_HISTORY];
 int          move_history_pointer;
 
-float komi;
+float komi = 0.0;
 int movenum;
 int allow_suicide = 0;  /* allow opponent to make suicide moves */
 
 
-char shadow[BOARDMAX];
+signed char shadow[BOARDMAX];
 
 /* Hashing of positions. */
 Hash_data board_hash;
