@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003 and 2004                   *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -16,7 +16,7 @@
  *                                                                   *
  * You should have received a copy of the GNU General Public         *
  * License along with this program; if not, write to the Free        *
- * Software Foundation, Inc., 59 Temple Place - Suite 330,           *
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
  * Boston, MA 02111, USA.                                            *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -60,8 +60,6 @@
 /* Datas and other stuff */
 /*************************/
 
-extern int board_size;
-
 typedef struct {
 
   /* clock parameters */
@@ -577,7 +575,6 @@ keep_ahead(int color)
 void
 clock_adapt_level(int *p_level, int color)
 {
-  int old_level;
   double hurry_limit, safe_limit;
 
   /* 
@@ -589,8 +586,6 @@ clock_adapt_level(int *p_level, int color)
     clk.levels[clk.moveno + 1] = clk.level;
     return;
   }
-
-  old_level = *p_level;
   
   /* 
    * Hurry strategy:
