@@ -65,7 +65,8 @@ static int connected_to_eye(int pos, int str, int color, int eye_color,
 			    struct eye_data *eye);
 static void connected_to_eye_recurse(int pos, int str, int color,
 				     int eye_color, struct eye_data *eye,
-				     char *mx, char *me, int *halfeyes);
+				     signed char *mx, signed char *me,
+				     int *halfeyes);
 static int compute_crude_status(int pos);
 static int compute_escape(int pos, int dragon_status_known);
 static void compute_surrounding_moyo_sizes(const struct influence_data *q);
@@ -1090,7 +1091,7 @@ dragon_looks_inessential(int origin)
  * owl code thinks so.
  */
 static void
-get_alive_stones(int color, char safe_stones[BOARDMAX])
+get_alive_stones(int color, signed char safe_stones[BOARDMAX])
 {
   int d;
   get_lively_stones(color, safe_stones);
@@ -1154,7 +1155,8 @@ identify_thrashing_dragons()
 	  DEBUG(DEBUG_DRAGONS,
 		"neighbor at distance %d of thrashing dragon found at %1m\n",
 		dist + 1, DRAGON(d).origin);
-	  mark_dragon(DRAGON(d).origin, thrashing_stone, (char)(dist + 1));
+	  mark_dragon(DRAGON(d).origin, thrashing_stone,
+		      (signed char)(dist + 1));
 	}
       }
     }
@@ -1163,7 +1165,7 @@ identify_thrashing_dragons()
 
 
 static void
-set_dragon_strengths(const char safe_stones[BOARDMAX],
+set_dragon_strengths(const signed char safe_stones[BOARDMAX],
     		     float strength[BOARDMAX])
 {
   int ii;
@@ -1183,7 +1185,7 @@ set_dragon_strengths(const char safe_stones[BOARDMAX],
  * everything else unchanged.
  */
 void
-mark_inessential_stones(int color, char safe_stones[BOARDMAX])
+mark_inessential_stones(int color, signed char safe_stones[BOARDMAX])
 {
   int ii;
   for (ii = BOARDMIN; ii < BOARDMAX; ii++)
@@ -1202,7 +1204,7 @@ mark_inessential_stones(int color, char safe_stones[BOARDMAX])
 }
 
 void
-set_strength_data(int color, char safe_stones[BOARDMAX],
+set_strength_data(int color, signed char safe_stones[BOARDMAX],
     		  float strength[BOARDMAX])
 {
   gg_assert(IS_STONE(color) || color == EMPTY);
@@ -1216,7 +1218,7 @@ set_strength_data(int color, char safe_stones[BOARDMAX],
 void
 compute_dragon_influence()
 {
-  char safe_stones[BOARDMAX];
+  signed char safe_stones[BOARDMAX];
   float strength[BOARDMAX];
 
   set_strength_data(BLACK, safe_stones, strength);
@@ -1412,8 +1414,8 @@ static int
 connected_to_eye(int pos, int str, int color, int eye_color,
 		 struct eye_data *eye)
 {
-  char mx[BOARDMAX];
-  char me[BOARDMAX];
+  signed char mx[BOARDMAX];
+  signed char me[BOARDMAX];
   int k;
   int halfeyes;
 
@@ -1442,7 +1444,7 @@ connected_to_eye(int pos, int str, int color, int eye_color,
  */
 static void
 connected_to_eye_recurse(int pos, int str, int color, int eye_color,
-			 struct eye_data *eye, char *mx, char *me,
+			 struct eye_data *eye, signed char *mx, signed char *me,
 			 int *halfeyes)
 {
   int liberties;
@@ -1848,8 +1850,8 @@ compute_crude_status(int pos)
  * in the goal array.
  */
 int
-dragon_escape(char goal[BOARDMAX], int color,
-	      char escape_value[BOARDMAX])
+dragon_escape(signed char goal[BOARDMAX], int color,
+	      signed char escape_value[BOARDMAX])
 {
   int ii;
   int k;
@@ -2003,9 +2005,9 @@ static int
 compute_escape(int pos, int dragon_status_known)
 {
   int ii;
-  char goal[BOARDMAX];
-  char escape_value[BOARDMAX];
-  char safe_stones[BOARDMAX];
+  signed char goal[BOARDMAX];
+  signed char escape_value[BOARDMAX];
+  signed char safe_stones[BOARDMAX];
 
   ASSERT1(IS_STONE(board[pos]), pos);
 
@@ -2284,7 +2286,7 @@ are_neighbor_dragons(int d1, int d2)
 
 /* Mark the stones of a dragon. */
 void
-mark_dragon(int pos, char mx[BOARDMAX], char mark)
+mark_dragon(int pos, signed char mx[BOARDMAX], signed char mark)
 {
   int w;
   for (w = first_worm_in_dragon(dragon[pos].origin); w != NO_MOVE;
@@ -2406,11 +2408,9 @@ size_of_biggest_critical_dragon(void)
 void
 ascii_report_dragon(char *string)
 {
-  int m, n, pos;
+  int pos = string_to_location(board_size, string);
 
-  string_to_location(board_size, string, &m, &n);
-  pos = POS(m, n);
-  if (!ON_BOARD1(pos))
+  if (!ON_BOARD(pos))
     fprintf(stderr, "unknown position %s\n", string);
   else
     report_dragon(stderr, pos);
