@@ -39,7 +39,7 @@
  * number of stones actually residing on the board. This does in
  * particular include handicap stones.
  */
-#define MAX_FUSEKI_DATABASE_STONES 19
+#define MAX_FUSEKI_DATABASE_STONES 30
 
 
 #define UPPER_LEFT  0
@@ -267,7 +267,7 @@ static void
 fuseki_callback(int move, struct fullboard_pattern *pattern, int ll)
 {
   TRACE("Fuseki database move at %1m with relative weight %d, pattern %s+%d\n",
-	move, (int) pattern->value, pattern->name, ll);
+	move, pattern->value, pattern->name, ll);
 
   /* Store coordinates and relative weight for the found move. */
   fuseki_moves[num_fuseki_moves] = move;
@@ -313,15 +313,10 @@ search_fuseki_database(int color)
     return 0;
 
   /* Choose randomly with respect to relative weights for matched moves.
-   * Do not choose moves with less value than 20% of the best move
-   * if there are more than two moves on board.
    */
   best_fuseki_value = fuseki_value[0];
   q = gg_rand() % fuseki_total_value;
   for (k = 0; k < num_fuseki_moves; k++) {
-    if (stones_on_board(BLACK | WHITE) > 2
-	&& fuseki_value[k] < (best_fuseki_value / 5))
-      break;
     q -= fuseki_value[k];
     if (q < 0)
       break;
