@@ -50,7 +50,7 @@ void clearstats(void);
 
 void transformation_init(void);
 
-void report_worm(int m, int n);
+void report_worm(int pos);
 void ascii_report_worm(char *string);
 void report_dragon(FILE *outfile, int pos);
 void ascii_report_dragon(char *string);
@@ -175,8 +175,6 @@ struct corner_pattern;
 struct corner_db;
 struct half_eye_data;
 struct movelist;
-struct tree_node_list;
-struct match_node;
 
 /*
  * Try to match a pattern in the database to the board. Callbacks for
@@ -194,20 +192,15 @@ typedef void (*corner_matchpat_callback_fn_ptr)(int move, int color,
 						int *stones, int num_stones);
 void matchpat(matchpat_callback_fn_ptr callback, int color,
 	      struct pattern_db *pdb, void *callback_data,
-	      char goal[BOARDMAX]);
+	      signed char goal[BOARDMAX]);
 void matchpat_goal_anchor(matchpat_callback_fn_ptr callback, int color,
 	      struct pattern_db *pdb, void *callback_data,
-	      char goal[BOARDMAX], int anchor_in_goal);
+	      signed char goal[BOARDMAX], int anchor_in_goal);
 void fullboard_matchpat(fullboard_matchpat_callback_fn_ptr callback,
 			int color, struct fullboard_pattern *pattern);
 void corner_matchpat(corner_matchpat_callback_fn_ptr callback, int color,
 		     struct corner_db *database);
 void dfa_match_init(void);
-void tree_match_init(void);
-void tree_initialize_pointers(struct tree_node_list *tnl,
-                              struct match_node *matches,
-                              int tnl_size,
-                              int matches_size);
 
 void reading_cache_init(int bytes);
 void reading_cache_clear(void);
@@ -250,7 +243,7 @@ void store_persistent_connection_cache(enum routine_id routine,
 				       int str1, int str2,
 				       int result, int move,
 				       int tactical_nodes,
-				       char connection_shadow[BOARDMAX]);
+				       signed char connection_shadow[BOARDMAX]);
 int search_persistent_breakin_cache(enum routine_id routine,
 				    int str, Hash_data *goal_hash,
 				    int breakin_node_limit,
@@ -260,7 +253,7 @@ void store_persistent_breakin_cache(enum routine_id routine,
 				    int result, int move,
 				    int tactical_nodes,
 				    int breakin_node_limit,
-				    char breakin_shadow[BOARDMAX]);
+				    signed char breakin_shadow[BOARDMAX]);
 int search_persistent_owl_cache(enum routine_id routine,
 				int apos, int bpos, int cpos,
 				int *result, int *move, int *move2,
@@ -268,7 +261,7 @@ int search_persistent_owl_cache(enum routine_id routine,
 void store_persistent_owl_cache(enum routine_id routine,
 				int apos, int bpos, int cpos,
 				int result, int move, int move2, int certain,
-				int tactical_nodes, char goal[BOARDMAX],
+				int tactical_nodes, signed char goal[BOARDMAX],
 				int goal_color);
 void owl_hotspots(float values[BOARDMAX]);
 int search_persistent_semeai_cache(enum routine_id routine,
@@ -281,7 +274,8 @@ void store_persistent_semeai_cache(enum routine_id routine,
 				   Hash_data *goal_hash,
 				   int resulta, int resultb,
 				   int move, int certain, int tactical_nodes,
-				   char goala[BOARDMAX], char goalb[BOARDMAX]);
+				   signed char goala[BOARDMAX],
+				   signed char goalb[BOARDMAX]);
 
 
 /* readconnect.c */
@@ -290,8 +284,8 @@ int disconnect(int str1, int str2, int *move);
 int fast_disconnect(int str1, int str2, int *move);
 int non_transitivity(int str1, int str2, int str3, int *move);
 
-int break_in(int str, const char goal[BOARDMAX], int *move);
-int block_off(int str1, const char goal[BOARDMAX], int *move);
+int break_in(int str, const signed char goal[BOARDMAX], int *move);
+int block_off(int str1, const signed char goal[BOARDMAX], int *move);
 
 int obvious_false_eye(int pos, int color);
 void estimate_lunch_eye_value(int lunch, int *min, int *probable, int *max,
@@ -299,12 +293,12 @@ void estimate_lunch_eye_value(int lunch, int *min, int *probable, int *max,
 int owl_topological_eye(int pos, int color);
 int vital_chain(int pos);
 int confirm_safety(int move, int color, int *defense_point,
-		   char safe_stones[BOARDMAX]);
+		   signed char safe_stones[BOARDMAX]);
 int dragon_weak(int pos);
 float dragon_weakness(int pos, int ignore_dead_dragons);
 int size_of_biggest_critical_dragon(void);
 float blunder_size(int move, int color, int *defense_point,
-		   char safe_stones[BOARDMAX]);
+		   signed char safe_stones[BOARDMAX]);
 void set_depth_values(int level, int report_levels);
 void modify_depth_values(int n);
 void increase_depth_values(void);
@@ -318,7 +312,8 @@ int does_secure(int color, int move, int pos);
 
 void compute_new_dragons(int dragon_origins[BOARDMAX]);
 void join_dragons(int d1, int d2);
-int dragon_escape(char goal[BOARDMAX], int color, char escape_value[BOARDMAX]);
+int dragon_escape(signed char goal[BOARDMAX], int color,
+		  signed char escape_value[BOARDMAX]);
 void compute_refined_dragon_weaknesses(void);
 
 struct eyevalue;
@@ -328,16 +323,16 @@ float crude_dragon_weakness(int safety, struct eyevalue *genus, int has_lunch,
 
 int is_same_dragon(int d1, int d2);
 int are_neighbor_dragons(int d1, int d2);
-void mark_dragon(int pos, char mx[BOARDMAX], char mark);
+void mark_dragon(int pos, signed char mx[BOARDMAX], signed char mark);
 int first_worm_in_dragon(int d);
 int next_worm_in_dragon(int w);
 int lively_dragon_exists(int color);
 void compute_dragon_influence(void);
-void set_strength_data(int color, char safe_stones[BOARDMAX],
+void set_strength_data(int color, signed char safe_stones[BOARDMAX],
 		       float strength[BOARDMAX]);
-void mark_inessential_stones(int color, char safe_stones[BOARDMAX]);
+void mark_inessential_stones(int color, signed char safe_stones[BOARDMAX]);
 
-void get_lively_stones(int color, char safe_stones[BOARDMAX]);
+void get_lively_stones(int color, signed char safe_stones[BOARDMAX]);
 int is_same_worm(int w1, int w2);
 int is_worm_origin(int w, int pos);
 void propagate_worm(int pos);
@@ -424,12 +419,12 @@ int is_known_good_attack_threat(int move, int target);
 
 int get_attack_threats(int pos, int max_strings, int strings[]);
 int get_defense_threats(int pos, int max_strings, int strings[]);
-void get_saved_worms(int pos, char saved[BOARDMAX]);
-void get_saved_dragons(int pos, char saved[BOARDMAX]);
+void get_saved_worms(int pos, signed char saved[BOARDMAX]);
+void get_saved_dragons(int pos, signed char saved[BOARDMAX]);
 void mark_safe_stones(int color, int move_pos,
-		      const char saved_dragons[BOARDMAX],
-		      const char saved_worms[BOARDMAX],
-		      char safe_stones[BOARDMAX]);
+		      const signed char saved_dragons[BOARDMAX],
+		      const signed char saved_worms[BOARDMAX],
+		      signed char safe_stones[BOARDMAX]);
 
 
 int owl_lively(int pos);
@@ -475,14 +470,16 @@ void endgame(int color);
 void endgame_shapes(int color);
 
 void combinations(int color);
-int atari_atari(int color, int *attack_move, char defense_moves[BOARDMAX],
+int atari_atari(int color, int *attack_move,
+		signed char defense_moves[BOARDMAX],
 		int save_verbose);
 int atari_atari_confirm_safety(int color, int tpos, int *move, int minsize,
-			       const char saved_dragons[BOARDMAX],
-			       const char saved_worms[BOARDMAX]);
+			       const signed char saved_dragons[BOARDMAX],
+			       const signed char saved_worms[BOARDMAX]);
 
-int atari_atari_blunder_size(int color, int tpos, char defense_moves[BOARDMAX],
-			     const char safe_stones[BOARDMAX]);
+int atari_atari_blunder_size(int color, int tpos,
+			     signed char defense_moves[BOARDMAX],
+			     const signed char safe_stones[BOARDMAX]);
 
 int review_move_reasons(int *move, float *value, int color,
 			float pure_threat_value, float our_score,
@@ -541,7 +538,7 @@ int semeai_move_reason_known(int move, int dr);
 int does_attack(int move, int str);
 int does_defend(int move, int str);
 int double_atari(int move, int color, float *value,
-		 char safe_stones[BOARDMAX]);
+		 signed char safe_stones[BOARDMAX]);
 int send_two_return_one(int move, int color);
 int play_attack_defend_n(int color, int do_attack, int num_moves, ...);
 int play_attack_defend2_n(int color, int do_attack, int num_moves, ...);
@@ -609,17 +606,18 @@ extern struct influence_data followup_influence;
 #define DEFAULT_STRENGTH 100.0
 
 /* Influence functions. */
-void compute_influence(int color, const char safe_stones[BOARDMAX],
+void compute_influence(int color, const signed char safe_stones[BOARDMAX],
 		       const float strength[BOARDMAX],
 		       struct influence_data *q,
 		       int move, const char *trace_message);
 void compute_followup_influence(const struct influence_data *base,
 			        struct influence_data *q, 
 		                int move, const char *trace_message);
-void compute_escape_influence(int color, const char safe_stones[BOARDMAX],
-			      const char goal[BOARDMAX],
+void compute_escape_influence(int color,
+			      const signed char safe_stones[BOARDMAX],
+			      const signed char goal[BOARDMAX],
 			      const float strength[BOARDMAX],
-                              char escape_value[BOARDMAX]);
+                              signed char escape_value[BOARDMAX]);
 
 float influence_delta_territory(const struct influence_data *base,
 	                        const struct influence_data *q, int color,
@@ -682,7 +680,7 @@ int analyze_eyegraph(const char *coded_eyegraph, struct eyevalue *value,
 
 
 /* debugging support */
-void goaldump(const char goal[BOARDMAX]);
+void goaldump(const signed char goal[BOARDMAX]);
 void move_considered(int move, float value);
 
 
@@ -750,7 +748,7 @@ extern int cosmic_gnugo;             /* use center oriented influence */
 extern int large_scale;              /* seek large scale captures */
 
 extern int thrashing_dragon;        /* Dead opponent's dragon trying to live */
-extern char thrashing_stone[BOARDMAX];        /* All thrashing stones. */
+extern signed char thrashing_stone[BOARDMAX];       /* All thrashing stones. */
 
 /* Experimental reading */
 extern char *rgoal;
@@ -789,21 +787,16 @@ extern double total_time;
 
 
 struct eyevalue {
-#if 0
-  char maxeye;       /* number of eyes if defender plays first               */
-  char mineye;       /* number of eyes if attacker plays first               */
-#else
   unsigned char a; /* number of eyes if attacker plays first twice */
   unsigned char b; /* number of eyes if attacker plays first */
   unsigned char c; /* number of eyes if defender plays first */
   unsigned char d; /* number of eyes if defender plays first twice */
-#endif
 };
 
 
 struct half_eye_data {
   float value;          /* Topological eye value. */
-  char type;            /* HALF_EYE or FALSE_EYE; */
+  unsigned char type;   /* HALF_EYE or FALSE_EYE; */
   int num_attacks;      /* number of attacking points */
   int attack_point[4];  /* the moves to attack a topological halfeye */
   int num_defenses;     /* number of defending points */
@@ -863,8 +856,8 @@ extern struct worm_data worm[BOARDMAX];
 #define MAX_SURROUND 10
 
 struct surround_data {
-  int dragon_number;           /* number of the (surrounded) beast */
-  char surround_map[BOARDMAX]; /* surround map                     */
+  int dragon_number;                  /* number of the (surrounded) beast */
+  signed char surround_map[BOARDMAX]; /* surround map                     */
 };
 
 extern struct surround_data surroundings[MAX_SURROUND];
@@ -990,9 +983,9 @@ struct eye_data {
   /* ---------------------------------------------------------------- */
   /* The below fields are not.                                        */
 
-  char marginal;             /* This vertex is marginal               */
-  char neighbors;            /* number of neighbors in eyespace       */
-  char marginal_neighbors;   /* number of marginal neighbors          */
+  unsigned char marginal;             /* This vertex is marginal               */
+  unsigned char neighbors;            /* number of neighbors in eyespace       */
+  unsigned char marginal_neighbors;   /* number of marginal neighbors          */
 };
 
 struct vital_eye_points {
