@@ -36,14 +36,6 @@
 /* Pattern profiling functions:                                           */
 /**************************************************************************/
 
-/* define this to see how each phase of pattern rejection is performing */
-/* #define PROFILE_MATCHER */
-
-
-#ifdef PROFILE_MATCHER
-static int totals[6];
-#endif
-
 
 #if PROFILE_PATTERNS
 /* Initialize pattern profiling fields in one pattern struct array. */
@@ -147,11 +139,11 @@ static void fixup_patterns_for_board_size(struct pattern *pattern);
 static void prepare_for_match(int color);
 static void do_matchpat(int anchor, matchpat_callback_fn_ptr callback,
 			int color, struct pattern *database,
-			void *callback_data, char goal[BOARDMAX]);
+			void *callback_data, signed char goal[BOARDMAX]);
 static void matchpat_loop(matchpat_callback_fn_ptr callback, 
 			  int color, int anchor,
 			  struct pattern_db *pdb, void *callback_data,
-			  char goal[BOARDMAX], int anchor_in_goal);
+			  signed char goal[BOARDMAX], int anchor_in_goal);
 
 /* Precomputed tables to allow rapid checks on the piece at
  * the board. This table relies on the fact that color is
@@ -319,7 +311,7 @@ transform2(int i, int j, int *ti, int *tj, int trans)
 static void
 do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 	    struct pattern *pattern, void *callback_data,
-	    char goal[BOARDMAX]) 
+	    signed char goal[BOARDMAX]) 
 {
   const int anchor_test = board[anchor] ^ color;  /* see below */
   int m = I(anchor);
@@ -382,13 +374,7 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
        */
 
       if (anchor_test != pattern->anchored_at_X)
-      {
-#ifdef PROFILE_MATCHER
-	/* oops - need to work out something we deferred */
-        totals[0] += (pattern->trfno == 5 ? 4 : pattern->trfno);
-#endif
 	continue;  /* does not match the anchor */
-      }
 
       ll = 0;  /* first transformation number */
       end_transformation = pattern->trfno;
@@ -399,10 +385,6 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 	end_transformation = 6;
       }
       
-#ifdef PROFILE_MATCHER
-      totals[0] += end_transformation - ll;
-#endif
-
       /* try each orientation transformation. Assume at least 1 */
 
       do {
@@ -411,10 +393,6 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 	int nodes_before;
 #endif
 	
-#ifdef PROFILE_MATCHER
-	++totals[1];
-#endif
-
 #if GRID_OPT == 1
 
 	/* We first perform the grid check : this checks up to 16
@@ -432,9 +410,6 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 
 #endif /* GRID_OPT == 1 */
 
-#ifdef PROFILE_MATCHER
-	++totals[2];
-#endif
 	/* Next, we do the range check. This applies the edge
 	 * constraints implicitly.
 	 */
@@ -460,10 +435,6 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 	    continue;  /* out of range */
 	}
 
-#ifdef PROFILE_MATCHER	 
-	++totals[3];
-#endif
-
 	/* Now iterate over the elements of the pattern. */
 	found_goal = 0;
 	for (k = 0; k < pattern->patlen; ++k) { /* match each point */
@@ -502,18 +473,10 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 #endif /* we don't trust the grid optimisation */
 
 
-#ifdef PROFILE_MATCHER
-	++totals[4];
-#endif
-
 	/* Make it here ==> We have matched all the elements to the board. */
 	if ((goal != NULL) && !found_goal)
 	  goto match_failed;
 
-#ifdef PROFILE_MATCHER
-	++totals[5];
-#endif
-
 #if PROFILE_PATTERNS
 	pattern->hits++;
 	nodes_before = stats.nodes;
@@ -535,14 +498,6 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
       } while (++ll < end_transformation); /* ll loop over symmetries */
     } /* if not rejected by maxwt */
   } while ((++pattern)->patn);  /* loop over patterns */
-
-
-#ifdef PROFILE_MATCHER
-  fprintf(stderr, 
-	  "total %d, anchor=%d, grid=%d, edge=%d, matched=%d, accepted=%d\n",
-	  totals[0], totals[1], totals[2], totals[3], totals[4], totals[5]);
-#endif
-
 }
 
 
@@ -554,7 +509,7 @@ do_matchpat(int anchor, matchpat_callback_fn_ptr callback, int color,
 static void
 matchpat_loop(matchpat_callback_fn_ptr callback, int color, int anchor,
 	      struct pattern_db *pdb, void *callback_data,
-	      char goal[BOARDMAX], int anchor_in_goal) 
+	      signed char goal[BOARDMAX], int anchor_in_goal) 
 {
   int pos;
   
@@ -565,195 +520,6 @@ matchpat_loop(matchpat_callback_fn_ptr callback, int color, int anchor,
   }
 }
 
-#if EXPERIMENTAL_READING
-
-/**************************************************************************/
-/* Tree matcher:                                                           */
-/**************************************************************************/
-static void tree_prepare_for_match(int color);
-static void tree_matchpat_loop(matchpat_callback_fn_ptr callback, 
-			       int color, int anchor,
-			       struct pattern_db *pdb, void *callback_data,
-			       char goal[BOARDMAX], int anchor_in_goal);
-static void tree_do_matchpat(int m, int n, matchpat_callback_fn_ptr callback,
-			     int color, struct pattern_db *database,
-			     void *callback_data, char goal[BOARDMAX],
-                             int anchor_in_goal);
-
-
-void
-tree_match_init(void)
-{
-  init_tree_read_attack();
-  init_tree_read_defend();
-  init_tree_owl_attackpat();
-  init_tree_owl_defendpat();
-  init_tree_owl_vital_apat();
-}
-
-
-static void 
-tree_prepare_for_match(int color)
-{
-  UNUSED(color);
-  /* Nothing to prepare! */
-}
-
-static void 
-tree_matchpat_loop(matchpat_callback_fn_ptr callback, 
-		   int color, int anchor,
-		   struct pattern_db *pdb, void *callback_data,
-		   char goal[BOARDMAX], int anchor_in_goal)
-{
-  int i, j;
-
-  for (i = 0; i != board_size; i++)
-    for (j = 0; j != board_size; j++)
-      if (BOARD(i, j) == anchor
-          && (!anchor_in_goal || goal[POS(i, j)] != 0))
-	tree_do_matchpat(i, j, callback, color, 
-			 pdb, callback_data, goal, anchor_in_goal);
-
-}
-
-/* Possibly cheaper to pass a little less recursively.
- * Note: This could even just be static data, unless the
- * tree pattern matcher is itself used recursively.*/
-struct rec_data {
-  matchpat_callback_fn_ptr callback;
-  struct pattern_db *database;
-  void *callback_data;
-};
-
-
-/* Recursively walks the tree data structure, calling the callback
- * for all patterns matched at location (m,n).
- */
-static void 
-do_tree_matchpat_rec(int color, int m, int n, int goal_found,
-                     char goal[BOARDMAX], 
-                     struct tree_node_list *tnl, 
-                     struct rec_data *pdata)
-{
-  if (0 && !tnl)
-    return;
-
-  tnl = tnl->next;
-  while (tnl) {
-    struct tree_node *node = &(tnl->node);
-    int x = m + node->x;
-    int y = n + node->y;
-    if (ON_BOARD2(x, y)) {
-      int att = node->att;
-      int point_color = BOARD(x, y);
-      if ((att == EMPTY && point_color == EMPTY)
-          || (att == ATT_X && point_color == OTHER_COLOR(color))
-          || (att == ATT_O && point_color == color)) {
-        goal_found = goal_found || goal[POS(x, y)];
-        if (node->matches) {
-          struct match_node *match = node->matches->next;
-          while (match) {
-            struct pattern *pattern =
-	      &(pdata->database->patterns[match->patnum]);
-            int ll = match->orientation;
-	    int mi, mj, xi, xj;
-	    TRANSFORM2(pattern->mini, pattern->minj, &mi, &mj, ll);
-	    TRANSFORM2(pattern->maxi, pattern->maxj, &xi, &xj, ll);
-	    /* now do the range-check */
-            if (!goal_found
-                || !ON_BOARD2(m+mi, n+mj) 
-                || !ON_BOARD2(m+xi, n+xj)) {
-	      ;/* goal not found, or out of range */
-            }
-	    else {
-              if (0) {
-                gprintf("  P[%s, %d] matches at %m)\n",
-			pattern->name, match->orientation, x, y);
-              }
-              /* A match! */
-              pdata->callback(POS(m, n), color, pattern, ll,
-			      pdata->callback_data);
-            }
-
-            match = match->next;
-          }
-        }
-        if (node->next_list && node->next_list->next) {
-          do_tree_matchpat_rec(color, m, n, goal_found, goal,
-			       node->next_list, pdata);
-        }
-      }
-    }
-    tnl = tnl->next;
-  }
-}
-
-/* Stub for matchpat function.  Work done in recursive helper. */
-static void 
-tree_do_matchpat(int m, int n, matchpat_callback_fn_ptr callback,
-		 int color, struct pattern_db *database,
-		 void *callback_data, char goal[BOARDMAX],
-		 int anchor_in_goal)
-{
-  struct tree_node_list *tree = database->tnl;
-  struct rec_data data;
-
-  if (0) {
-    if (0)
-      showboard(0);
-    gprintf("Trying to match at %m\n", m, n);
-  }
-  data.callback = callback;
-  data.callback_data = callback_data;
-  data.database = database;
-
-  /* note: If anchor_in_goal is 0, then the goal_found parameter is
-   *   always trivially true.  This will short-circuit some array
-   *   lookups in the recursive version.
-   */
-  do_tree_matchpat_rec(color, m, n, !anchor_in_goal, goal, tree, &data);
-}
-
-/**************************************************************************/
-/* Tree initialization helper                                             */
-/**************************************************************************/
-
-/* The tree data structure is output with raw integer offsets
- * relative to a single array of tree_node_list and match_node
- * elements.  These offsets need to be added to the actual base
- * address of the list of elements for the pointers to be
- * meaningful.
- *
- * FIXME: This code is not portable. On certain platforms the size of
- *        a pointer and the size of an int differ.
- */
-void 
-tree_initialize_pointers(struct tree_node_list *tnl,
-                         struct match_node *matches,
-                         int tnl_size,
-                         int matches_size)
-{
-  struct tree_node_list *tnl_walk = tnl;
-  struct match_node *matches_walk = matches;
-
-  do {
-    if (tnl_walk->next)
-      tnl_walk->next = tnl + (int)(tnl_walk->next);
-    if (tnl_walk->node.matches)
-      tnl_walk->node.matches = matches + (int)(tnl_walk->node.matches);
-    if (tnl_walk->node.next_list)
-      tnl_walk->node.next_list = tnl + (int)(tnl_walk->node.next_list);
-  } while (++tnl_walk < tnl + tnl_size);
-
-
-  do {
-    if (matches_walk->next)
-      matches_walk->next = matches + (int)(matches_walk->next);
-  } while (++matches_walk < matches + matches_size);  
-}
-
-#endif
-
 
 /**************************************************************************/
 /* DFA matcher:                                                           */
@@ -782,18 +548,18 @@ static int scan_for_patterns(dfa_rt_t *pdfa, int l, int *dfa_pos,
 static void do_dfa_matchpat(dfa_rt_t *pdfa,
 			    int anchor, matchpat_callback_fn_ptr callback,
 			    int color, struct pattern *database,
-			    void *callback_data, char goal[BOARDMAX],
+			    void *callback_data, signed char goal[BOARDMAX],
                             int anchor_in_goal);
 static void check_pattern_light(int anchor, 
 				matchpat_callback_fn_ptr callback,
 				int color, struct pattern *pattern, int ll,
 				void *callback_data,
-				char goal[BOARDMAX],
+				signed char goal[BOARDMAX],
                                 int anchor_in_goal);
 static void dfa_matchpat_loop(matchpat_callback_fn_ptr callback,
 			      int color, int anchor,
 			      struct pattern_db *pdb, void *callback_data,
-			      char goal[BOARDMAX], int anchor_in_goal);
+			      signed char goal[BOARDMAX], int anchor_in_goal);
 
 
 /***********************************************************************/
@@ -916,7 +682,7 @@ static void
 do_dfa_matchpat(dfa_rt_t *pdfa,
 		int anchor, matchpat_callback_fn_ptr callback,
 		int color, struct pattern *database,
-		void *callback_data, char goal[BOARDMAX],
+		void *callback_data, signed char goal[BOARDMAX],
 		int anchor_in_goal)
 {
   int k;
@@ -967,7 +733,7 @@ do_dfa_matchpat(dfa_rt_t *pdfa,
 static void
 check_pattern_light(int anchor, matchpat_callback_fn_ptr callback, int color,
 		    struct pattern *pattern, int ll, void *callback_data,
-		    char goal[BOARDMAX], int anchor_in_goal)
+		    signed char goal[BOARDMAX], int anchor_in_goal)
 {
   int k;			/* Iterate over elements of pattern */
   int found_goal = 0;
@@ -976,10 +742,6 @@ check_pattern_light(int anchor, matchpat_callback_fn_ptr callback, int color,
   int nodes_before;
 #endif
   
-#ifdef PROFILE_MATCHER
-  ++totals[1];
-#endif
-
   if (0)
     gprintf("check_pattern_light @ %1m rot:%d pattern: %s\n", 
 	    anchor, ll, pattern->name);
@@ -1024,10 +786,6 @@ check_pattern_light(int anchor, matchpat_callback_fn_ptr callback, int color,
       goto match_failed;
   }
 
-#ifdef PROFILE_MATCHER
-  ++totals[4];
-#endif
-
 #if PROFILE_PATTERNS
   pattern->hits++;
   nodes_before = stats.nodes;
@@ -1056,7 +814,7 @@ check_pattern_light(int anchor, matchpat_callback_fn_ptr callback, int color,
 static void
 dfa_matchpat_loop(matchpat_callback_fn_ptr callback, int color, int anchor,
 		  struct pattern_db *pdb, void *callback_data,
-		  char goal[BOARDMAX], int anchor_in_goal) 
+		  signed char goal[BOARDMAX], int anchor_in_goal) 
 {
   int pos;
 
@@ -1077,7 +835,7 @@ dfa_matchpat_loop(matchpat_callback_fn_ptr callback, int color, int anchor,
 typedef void (*loop_fn_ptr_t)(matchpat_callback_fn_ptr callback, 
 			      int color, int anchor,
 			      struct pattern_db *pdb, void *callback_data,
-			      char goal[BOARDMAX], int anchor_in_goal);
+			      signed char goal[BOARDMAX], int anchor_in_goal);
 
 typedef void (*prepare_fn_ptr_t)(int color);
 
@@ -1094,7 +852,7 @@ typedef void (*prepare_fn_ptr_t)(int color);
 void
 matchpat(matchpat_callback_fn_ptr callback, int color,
 	 struct pattern_db *pdb, void *callback_data,
-	 char goal[BOARDMAX]) 
+	 signed char goal[BOARDMAX]) 
 {
   matchpat_goal_anchor(callback, color, pdb, callback_data, goal, 
                        pdb->fixed_anchor);
@@ -1103,7 +861,7 @@ matchpat(matchpat_callback_fn_ptr callback, int color,
 void 
 matchpat_goal_anchor(matchpat_callback_fn_ptr callback, int color,
 		     struct pattern_db *pdb, void *callback_data,
-		     char goal[BOARDMAX], int anchor_in_goal) 
+		     signed char goal[BOARDMAX], int anchor_in_goal) 
 {
   loop_fn_ptr_t loop = matchpat_loop;
   prepare_fn_ptr_t prepare = prepare_for_match;
@@ -1120,13 +878,6 @@ matchpat_goal_anchor(matchpat_callback_fn_ptr callback, int color,
     prepare = dfa_prepare_for_match;
   }
 
-#if EXPERIMENTAL_READING
-  if (pdb->tnl) {
-    loop = tree_matchpat_loop;
-    prepare = tree_prepare_for_match;
-  }
-#endif
-
   /* select strategy */
   switch (color) {
     case ANCHOR_COLOR:
@@ -1155,6 +906,17 @@ matchpat_goal_anchor(matchpat_callback_fn_ptr callback, int color,
 }
 
 
+static int
+fullboard_transform(int pos, int trans)
+{
+  int dx = I(pos) - (board_size-1)/2;
+  int dy = J(pos) - (board_size-1)/2;
+  int x, y;
+  gg_assert(POS((board_size-1)/2, (board_size-1)/2) + DELTA(dx, dy) == pos);
+  TRANSFORM2(dx, dy, &x, &y, trans);
+  return POS(x + (board_size-1)/2, y + (board_size-1)/2);
+}
+
 /* A dedicated matcher which can only do fullboard matching on
  * odd-sized boards, optimized for fuseki patterns.
  */
@@ -1162,50 +924,56 @@ void
 fullboard_matchpat(fullboard_matchpat_callback_fn_ptr callback, int color,
 		   struct fullboard_pattern *pattern)
 {
-  int other = OTHER_COLOR(color);
   int ll;   /* Iterate over transformations (rotations or reflections)  */
-  int k;    /* Iterate over elements of pattern */
   /* We transform around the center point. */
-  int mid = POS((board_size-1)/2, (board_size-1)/2);
   int number_of_stones_on_board = stones_on_board(BLACK | WHITE);
+  static int color_map[gg_max(WHITE, BLACK) + 1];
+  /* One hash value for each rotation/reflection: */
+  Hash_data current_board_hash[8];
   
   /* Basic sanity check. */
   gg_assert(color != EMPTY);
   gg_assert(board_size % 2 == 1);
 
-  /* Try each pattern - NULL pattern marks end of list. */
-  for (; pattern->patn; pattern++) { 
-    /* The number of stones on the board must be right. This is not
-     * only an optimization because we never even look at the
-     * intersections which are empty in the pattern.
-     */
-    if (pattern->patlen != number_of_stones_on_board)
+  color_map[EMPTY] = EMPTY;
+  if (color == WHITE) {
+    color_map[WHITE] = WHITE;
+    color_map[BLACK] = BLACK;
+  }
+  else {
+    color_map[WHITE] = BLACK;
+    color_map[BLACK] = WHITE;
+  }
+
+  /* Get hash data of all rotations/reflections of current board position. */
+  for (ll = 0; ll < 8; ll++) {
+    Intersection p[BOARDSIZE];
+    int pos;
+    for (pos = 0; pos < BOARDSIZE; pos++)
+      if (ON_BOARD(pos))
+	p[pos] = color_map[board[fullboard_transform(pos, ll)]];
+      else
+	p[pos] = GRAY;
+
+    if (ON_BOARD(board_ko_pos))
+      hashdata_recalc(&current_board_hash[ll], p,
+		      fullboard_transform(board_ko_pos, ll));
+    else 
+      hashdata_recalc(&current_board_hash[ll], p, NO_MOVE);
+  }
+
+  /* Try each pattern - NULL pattern name marks end of list. */
+  for (; pattern->name; pattern++) { 
+    if (pattern->number_of_stones != number_of_stones_on_board)
       continue;
-    
-    /* try each orientation transformation */
-    for (ll = 0; ll < 8; ll++) {
-      /* Now iterate over the elements of the pattern. */
-      for (k = 0; k < pattern->patlen; k++) { /* match each point */
-	int pos; /* board co-ords of transformed pattern element */
-	int att = pattern->patn[k].att;  /* what we are looking for */
-
-	/* Work out the position on the board of this pattern element. */
-	pos = AFFINE_TRANSFORM(pattern->patn[k].offset, ll, mid);
-
-        ASSERT_ON_BOARD1(pos);
-
-	if ((att == ATT_O && board[pos] != color)
-	    || (att == ATT_X && board[pos] != other))
-	  break;
-	
-      } /* loop over elements */
-	
-      if (k == pattern->patlen) {
+    /* Try each orientation transformation. */
+    for (ll = 0; ll < 8; ll++)
+      if (hashdata_is_equal(current_board_hash[ll], pattern->fullboard_hash)) {
 	/* A match!  - Call back to the invoker to let it know. */
-	int pos = AFFINE_TRANSFORM(pattern->move_offset, ll, mid);
+	int pos = AFFINE_TRANSFORM(pattern->move_offset, ll,
+			           POS((board_size-1)/2, (board_size-1)/2));
 	callback(pos, pattern, ll);
       }
-    }
   }
 }
 
@@ -1257,7 +1025,7 @@ do_corner_matchpat(int num_variations, struct corner_variation *variation,
 {
   for (; --num_variations >= 0; variation++) {
     int move = AFFINE_TRANSFORM(variation->move_offset, trans, anchor);
-    char color_check = match_color ^ variation->xor_att;
+    int color_check = match_color ^ variation->xor_att;
     struct corner_pattern *pattern = variation->pattern;
 
     if (pattern && color_check == callback_color) {
