@@ -87,7 +87,7 @@
 struct persistent_cache_entry {
   int boardsize;
   int movenum;
-  char board[BOARDMAX];
+  Intersection board[BOARDMAX];
   int stack[MAX_CACHE_DEPTH];
   int move_color[MAX_CACHE_DEPTH];
   enum routine_id routine;
@@ -111,7 +111,7 @@ struct persistent_cache_entry {
  * This function has to be provided by each cache.
  */
 typedef void (*compute_active_area_fn)(struct persistent_cache_entry *entry,
-				       const char goal[BOARDMAX],
+				       const signed char goal[BOARDMAX],
 				       int goal_color);
 
 struct persistent_cache {
@@ -126,20 +126,22 @@ struct persistent_cache {
 };
 
 static void compute_active_owl_area(struct persistent_cache_entry *entry,
-				    const char goal[BOARDMAX],
+				    const signed char goal[BOARDMAX],
 				    int goal_color);
 static void compute_active_semeai_area(struct persistent_cache_entry *entry,
-				       const char goal[BOARDMAX],
+				       const signed char goal[BOARDMAX],
 				       int dummy);
 static void compute_active_reading_area(struct persistent_cache_entry *entry,
-					const char reading_shadow[BOARDMAX],
+					const signed char
+					    reading_shadow[BOARDMAX],
 					int dummy);
 static void compute_active_connection_area(struct persistent_cache_entry *entry,
-					   const char
+					   const signed char
 					   	connection_shadow[BOARDMAX],
 					   int goal_color);
 static void compute_active_breakin_area(struct persistent_cache_entry *entry,
-				        const char breakin_shadow[BOARDMAX],
+				        const signed char
+					    breakin_shadow[BOARDMAX],
 				        int dummy);
 
 static struct persistent_cache reading_cache =
@@ -172,7 +174,7 @@ static struct persistent_cache semeai_cache =
 
 
 static void
-draw_active_area(char board[BOARDMAX], int apos)
+draw_active_area(Intersection board[BOARDMAX], int apos)
 {
   int i, j, ii;
   int c = ' ';
@@ -219,7 +221,7 @@ draw_active_area(char board[BOARDMAX], int apos)
  * 0 otherwise.
  */
 static int
-verify_stored_board(char p[BOARDMAX])
+verify_stored_board(Intersection p[BOARDMAX])
 {
   int pos;
   for (pos = BOARDMIN; pos < BOARDMAX; pos++) {
@@ -467,7 +469,8 @@ store_persistent_cache(struct persistent_cache *cache,
 		       Hash_data *goal_hash,
 		       int result, int result2, int move, int move2,
 		       int certain, int node_limit,
-		       int cost, const char goal[BOARDMAX], int goal_color)
+		       int cost, const signed char goal[BOARDMAX],
+		       int goal_color)
 {
   int r;
   struct persistent_cache_entry *entry;
@@ -621,7 +624,7 @@ store_persistent_reading_cache(enum routine_id routine, int str,
 
 static void
 compute_active_reading_area(struct persistent_cache_entry *entry,
-			    const char goal[BOARDMAX], int dummy)
+			    const signed char goal[BOARDMAX], int dummy)
 {
   signed char active[BOARDMAX];
   int pos, r;
@@ -635,7 +638,7 @@ compute_active_reading_area(struct persistent_cache_entry *entry,
   for (pos = BOARDMIN; pos < BOARDMAX; pos++)
     active[pos] = goal[pos];
 
-  signed_mark_string(entry->apos, active, 1);
+  mark_string(entry->apos, active, 1);
 
   /* To be safe, also add the successful move. */
   if (entry->result != 0 && entry->move != 0)
@@ -652,7 +655,7 @@ compute_active_reading_area(struct persistent_cache_entry *entry,
 	|| (ON_BOARD(NORTH(pos)) && active[NORTH(pos)] == 1)
 	|| (ON_BOARD(EAST(pos)) && active[EAST(pos)] == 1)) {
       if (IS_STONE(board[pos]))
-	signed_mark_string(pos, active, 2);
+	mark_string(pos, active, 2);
       else
 	active[pos] = 2;
     }
@@ -822,7 +825,7 @@ void
 store_persistent_connection_cache(enum routine_id routine,
     				  int str1, int str2,
 				  int result, int move, int tactical_nodes,
-				  char connection_shadow[BOARDMAX])
+				  signed char connection_shadow[BOARDMAX])
 {
   store_persistent_cache(&connection_cache, routine,
       			 str1, str2, NO_MOVE, EMPTY, NULL,
@@ -836,7 +839,7 @@ store_persistent_connection_cache(enum routine_id routine,
  */
 static void
 compute_active_connection_area(struct persistent_cache_entry *entry,
-			       const char connection_shadow[BOARDMAX],
+			       const signed char connection_shadow[BOARDMAX],
 			       int dummy)
 {
   int pos;
@@ -858,8 +861,8 @@ compute_active_connection_area(struct persistent_cache_entry *entry,
   for (pos = BOARDMIN; pos < BOARDMAX; pos++)
     active[pos] = connection_shadow[pos];
 
-  signed_mark_string(entry->apos, active, 1);
-  signed_mark_string(entry->bpos, active, 1);
+  mark_string(entry->apos, active, 1);
+  mark_string(entry->bpos, active, 1);
 
   /* To be safe, also add the successful move. */
   if (entry->result != 0 && entry->move != 0)
@@ -877,7 +880,7 @@ compute_active_connection_area(struct persistent_cache_entry *entry,
 	if (board[pos] == EMPTY)
 	  active[pos] = k + 1;
 	else
-	  signed_mark_string(pos, active, (signed char) (k + 1));
+	  mark_string(pos, active, (signed char) (k + 1));
       }
     }
   }
@@ -889,7 +892,7 @@ compute_active_connection_area(struct persistent_cache_entry *entry,
     for (r = 0; r < 4; r++) {
       int pos2 = pos + delta[r];
       if (ON_BOARD(pos2) && board[pos2] != other && active[pos2] != 0) {
-	signed_mark_string(pos, active, 1);
+	mark_string(pos, active, 1);
 	break;
       }
     }
@@ -913,7 +916,7 @@ compute_active_connection_area(struct persistent_cache_entry *entry,
        */
       adj = chainlinks(pos, adjs);
       for (r = 0; r < adj; r++) {
-	signed_mark_string(adjs[r], active, -1);
+	mark_string(adjs[r], active, -1);
 	if (countlib(adjs[r]) <= 3) {
 	  int s;
 	  int adjs2[MAXCHAIN];
@@ -923,7 +926,7 @@ compute_active_connection_area(struct persistent_cache_entry *entry,
 	    active[libs[s]] = 1;
 	  adj2 = chainlinks(pos, adjs2);
 	  for (s = 0; s < adj2; s++)
-	    signed_mark_string(adjs2[s], active, -1);
+	    mark_string(adjs2[s], active, -1);
 	}
       }
     }
@@ -971,7 +974,7 @@ store_persistent_breakin_cache(enum routine_id routine,
     			       int str, Hash_data *goal_hash,
 			       int result, int move, int tactical_nodes,
 			       int breakin_node_limit,
-			       char breakin_shadow[BOARDMAX])
+			       signed char breakin_shadow[BOARDMAX])
 {
   store_persistent_cache(&breakin_cache, routine,
       			 str, NO_MOVE, NO_MOVE, EMPTY, goal_hash,
@@ -985,7 +988,8 @@ store_persistent_breakin_cache(enum routine_id routine,
  */
 static void
 compute_active_breakin_area(struct persistent_cache_entry *entry,
-			    const char breakin_shadow[BOARDMAX], int dummy)
+			    const signed char breakin_shadow[BOARDMAX],
+			    int dummy)
 {
   int pos;
   int k, r;
@@ -1006,7 +1010,7 @@ compute_active_breakin_area(struct persistent_cache_entry *entry,
   for (pos = BOARDMIN; pos < BOARDMAX; pos++)
     active[pos] = breakin_shadow[pos];
 
-  signed_mark_string(entry->apos, active, 1);
+  mark_string(entry->apos, active, 1);
 
   /* To be safe, also add the successful move. */
   if (entry->result != 0 && entry->move != 0)
@@ -1024,7 +1028,7 @@ compute_active_breakin_area(struct persistent_cache_entry *entry,
 	if (board[pos] == EMPTY)
 	  active[pos] = k + 1;
 	else
-	  signed_mark_string(pos, active, (signed char) (k + 1));
+	  mark_string(pos, active, (signed char) (k + 1));
       }
     }
   }
@@ -1038,7 +1042,7 @@ compute_active_breakin_area(struct persistent_cache_entry *entry,
       if (ON_BOARD(pos2)
 	  && board[pos2] != other
 	  && active[pos2] && active[pos2] <= 2) {
-	signed_mark_string(pos, active, 1);
+	mark_string(pos, active, 1);
 	break;
       }
     }
@@ -1062,7 +1066,7 @@ compute_active_breakin_area(struct persistent_cache_entry *entry,
        */
       adj = chainlinks(pos, adjs);
       for (r = 0; r < adj; r++) {
-	signed_mark_string(adjs[r], active, -1);
+	mark_string(adjs[r], active, -1);
 	if (countlib(adjs[r]) <= 3) {
 	  int s;
 	  int adjs2[MAXCHAIN];
@@ -1072,14 +1076,14 @@ compute_active_breakin_area(struct persistent_cache_entry *entry,
 	    active[libs[s]] = 1;
 	  adj2 = chainlinks(pos, adjs2);
 	  for (s = 0; s < adj2; s++)
-	    signed_mark_string(adjs2[s], active, -1);
+	    mark_string(adjs2[s], active, -1);
 	}
       }
     }
   }
   
   for (pos = BOARDMIN; pos < BOARDMAX; pos++) {
-    char value = board[pos];
+    Intersection value = board[pos];
     if (!ON_BOARD(pos))
       continue;
     if (!active[pos])
@@ -1112,7 +1116,7 @@ store_persistent_owl_cache(enum routine_id routine,
     			   int apos, int bpos, int cpos,
 			   int result, int move, int move2, int certain,
 			   int tactical_nodes,
-			   char goal[BOARDMAX], int goal_color)
+			   signed char goal[BOARDMAX], int goal_color)
 {
   store_persistent_cache(&owl_cache, routine, apos, bpos, cpos, EMPTY, NULL,
       			 result, NO_MOVE, move, move2, certain, owl_node_limit,
@@ -1127,7 +1131,7 @@ store_persistent_owl_cache(enum routine_id routine,
  * some intersection to be active.
  */
 static void
-compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
+compute_active_owl_type_area(const signed char goal[BOARDMAX], int goal_color,
 			     signed char active[BOARDMAX])
 {
   int k, r;
@@ -1158,7 +1162,7 @@ compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
 	if (board[pos] == EMPTY)
 	  active[pos] = k + 1;
 	else
-	  signed_mark_string(pos, active, (signed char) (k + 1));
+	  mark_string(pos, active, (signed char) (k + 1));
       }
     }
   }
@@ -1170,7 +1174,7 @@ compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
     for (r = 0; r < 4; r++) {
       int pos2 = pos + delta[r];
       if (ON_BOARD(pos2) && board[pos2] != other && active[pos2] != 0) {
-	signed_mark_string(pos, active, 1);
+	mark_string(pos, active, 1);
 	break;
       }
     }
@@ -1194,7 +1198,7 @@ compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
        */
       adj = chainlinks(pos, adjs);
       for (r = 0; r < adj; r++) {
-	signed_mark_string(adjs[r], active, -1);
+	mark_string(adjs[r], active, -1);
 	if (countlib(adjs[r]) <= 3) {
 	  int s;
 	  int adjs2[MAXCHAIN];
@@ -1204,7 +1208,7 @@ compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
 	    active[libs[s]] = 1;
 	  adj2 = chainlinks(pos, adjs2);
 	  for (s = 0; s < adj2; s++)
-	    signed_mark_string(adjs2[s], active, -1);
+	    mark_string(adjs2[s], active, -1);
 	}
       }
     }
@@ -1213,7 +1217,7 @@ compute_active_owl_type_area(const char goal[BOARDMAX], int goal_color,
 
 static void
 compute_active_owl_area(struct persistent_cache_entry *entry,
-			const char goal[BOARDMAX], int goal_color)
+			const signed char goal[BOARDMAX], int goal_color)
 {
   int pos;
   signed char active[BOARDMAX];
@@ -1269,9 +1273,10 @@ store_persistent_semeai_cache(enum routine_id routine,
 			      Hash_data *goal_hash,
     			      int resulta, int resultb, int move, int certain,
 			      int tactical_nodes,
-			      char goala[BOARDMAX], char goalb[BOARDMAX])
+			      signed char goala[BOARDMAX],
+			      signed char goalb[BOARDMAX])
 {
-  char goal[BOARDMAX];
+  signed char goal[BOARDMAX];
   int pos;
 
   for (pos = BOARDMIN; pos < BOARDMAX; pos++)
@@ -1286,7 +1291,7 @@ store_persistent_semeai_cache(enum routine_id routine,
 
 static void
 compute_active_semeai_area(struct persistent_cache_entry *entry,
-			   const char goal[BOARDMAX], int dummy)
+			   const signed char goal[BOARDMAX], int dummy)
 {
   int pos;
   signed char active_b[BOARDMAX];
@@ -1327,7 +1332,8 @@ compute_active_semeai_area(struct persistent_cache_entry *entry,
 /* Helper for the owl_hotspots() function below. */
 static void
 mark_dragon_hotspot_values(float values[BOARDMAX], int dr,
-			   float contribution, char active_board[BOARDMAX])
+			   float contribution,
+			   Intersection active_board[BOARDMAX])
 {
   int pos;
   int k;
