@@ -1700,7 +1700,7 @@ defense_callback(int anchor, int color, struct pattern *pattern, int ll,
 }
 
 void
-get_lively_stones(int color, char safe_stones[BOARDMAX])
+get_lively_stones(int color, signed char safe_stones[BOARDMAX])
 {
   int ii;
   memset(safe_stones, 0, BOARDMAX * sizeof(*safe_stones));
@@ -1720,7 +1720,7 @@ get_lively_stones(int color, char safe_stones[BOARDMAX])
 void
 compute_worm_influence()
 {
-  char safe_stones[BOARDMAX];
+  signed char safe_stones[BOARDMAX];
 
   get_lively_stones(BLACK, safe_stones);
   compute_influence(BLACK, safe_stones, NULL, &initial_black_influence,
@@ -1748,16 +1748,14 @@ compute_worm_influence()
 void
 ascii_report_worm(char *string)
 {
-  int m, n;
-  string_to_location(board_size, string, &m, &n);
-  report_worm(m, n);
+  int pos = string_to_location(board_size, string);
+  report_worm(pos);
 }
 
 
 void
-report_worm(int m, int n)
+report_worm(int pos)
 {
-  int pos = POS(m, n);
   int i;
 
   if (board[pos] == EMPTY) {
