@@ -102,7 +102,6 @@ enum {OPT_BOARDSIZE = 127,
       OPT_EXPERIMENTAL_OWL_EXT,
       OPT_SEMEAI_NODE_LIMIT,
       OPT_EXPERIMENTAL_CONNECTIONS,
-      OPT_EXPERIMENTAL_INFLUENCE,
       OPT_ALTERNATE_CONNECTIONS,
       OPT_WITH_BREAK_IN,
       OPT_WITHOUT_BREAK_IN,
@@ -113,7 +112,6 @@ enum {OPT_BOARDSIZE = 127,
       OPT_OPTIONS,
       OPT_STANDARD_SEMEAI,
       OPT_STANDARD_CONNECTIONS,
-      OPT_STANDARD_INFLUENCE,
       OPT_PRINT_LEVELS,
       OPT_DECIDE_POSITION,
       OPT_DECIDE_EYE,
@@ -148,8 +146,6 @@ enum {OPT_BOARDSIZE = 127,
       OPT_ALLOW_SUICIDE,
       OPT_CAPTURE_ALL_DEAD,
       OPT_PLAY_OUT_AFTERMATH,
-      OPT_ATTACK_BY_PATTERN,
-      OPT_DEFEND_BY_PATTERN,
       OPT_MIRROR,
       OPT_MIRROR_LIMIT,
       OPT_METAMACHINE,
@@ -292,8 +288,6 @@ static struct gg_option const long_options[] =
   {"score",          required_argument, 0, OPT_SCORE},
   {"printsgf",       required_argument, 0, OPT_PRINTSGF},
   {"profile-patterns", no_argument,     0, OPT_PROFILE_PATTERNS},
-  {"attack-by-pattern", no_argument,    0, OPT_ATTACK_BY_PATTERN},
-  {"defend-by-pattern", no_argument,    0, OPT_DEFEND_BY_PATTERN},
   {"mirror",         no_argument,       0, OPT_MIRROR},
   {"mirror-limit",   required_argument, 0, OPT_MIRROR_LIMIT},
   {"metamachine",    no_argument,       0, OPT_METAMACHINE},
@@ -343,49 +337,6 @@ main(int argc, char *argv[])
   int seed = 0;
   int seed_specified = 0;
 
-  komi = 0.0;
-  
-  level = DEFAULT_LEVEL;
-  min_level = 0;
-  max_level = 10;
-  
-  mandated_depth               = -1;
-  mandated_backfill_depth      = -1;
-  mandated_backfill2_depth     = -1;
-  mandated_break_chain_depth   = -1;
-  mandated_superstring_depth   = -1;
-  mandated_fourlib_depth       = -1;
-  mandated_ko_depth            = -1;
-  mandated_branch_depth        = -1;
-  mandated_owl_distrust_depth  = -1;
-  mandated_owl_branch_depth    = -1;
-  mandated_owl_reading_depth   = -1;
-  mandated_owl_node_limit      = -1;
-  mandated_aa_depth            = -1;
-
-  debug = 0;
-  fusekidb = 1;
-  disable_fuseki = 0;
-  josekidb = 1;
-  if (CHINESE_RULES)
-    chinese_rules = 1;
-  else 
-    chinese_rules = 0;
-  if (OWL_THREATS)
-    owl_threats = 1;
-  else
-    owl_threats = 0;
-  experimental_owl_ext = EXPERIMENTAL_OWL_EXT;
-  experimental_connections = EXPERIMENTAL_CONNECTIONS;
-  cosmic_gnugo = COSMIC_GNUGO;
-  large_scale = LARGE_SCALE;
-  resign_allowed = RESIGNATION_ALLOWED;
-
-  allow_suicide = 0;
-  capture_all_dead = 0;
-  play_out_aftermath = 0;
-  limit_search = 0;
-
   /* Default parameters for clock and auto level systems. */
   clock_init(3600, 0, 0);      /* One hour sudden death. */
 
@@ -508,9 +459,6 @@ main(int argc, char *argv[])
 	if (EXPERIMENTAL_OWL_EXT)
 	  fprintf(stdout,
 		  "configure option enabled: experimental GAIN/LOSS codes\n");
-	if (EXPERIMENTAL_READING)
-	  fprintf(stdout,
-		  "configure option enabled: experimental reading\n");
 	if (OWL_THREATS)
 	  fprintf(stdout,
 		  "configure option enabled: owl threats\n");
@@ -849,14 +797,12 @@ main(int argc, char *argv[])
 
       case OPT_LIMIT_SEARCH:
 	{
-	  int m, n;
-
-	  if (!string_to_location(board_size, gg_optarg, &m, &n)) {
+	  int pos = string_to_location(board_size, gg_optarg);
+	  if (pos == NO_MOVE) {
 	    fprintf(stderr, "gnugo: use --limit-search <pos>\n");
 	    return EXIT_FAILURE;
 	  }
-	  rotate(m, n, &m, &n, board_size, orientation);
-	  set_search_diamond(POS(m, n));
+	  set_search_diamond(pos);
 	}
 	break;
 
@@ -938,18 +884,6 @@ main(int argc, char *argv[])
 	return EXIT_SUCCESS;
 	break;
 	
-#if EXPERIMENTAL_READING
-
-      case OPT_ATTACK_BY_PATTERN:
-        attack_by_pattern = 1;
-        break;
-
-      case OPT_DEFEND_BY_PATTERN:
-        defend_by_pattern = 1;
-        break;
-
-#endif
-
       case OPT_MIRROR:
         play_mirror_go = 1;
         break;
@@ -1037,9 +971,8 @@ main(int argc, char *argv[])
   /* Notice that we need to know the board size before we can do this.
    */
   if (debuginfluence_move[0]) {
-    int m, n;
-    string_to_location(board_size, debuginfluence_move, &m, &n);
-    debug_influence_move(m, n);
+    int pos = string_to_location(board_size, debuginfluence_move);
+    debug_influence_move(pos);
   }
   
   /* Figure out a default mode if there was no explicit one. */
@@ -1145,140 +1078,140 @@ main(int argc, char *argv[])
     
   case MODE_DECIDE_STRING:
     {
-      int m, n;
+      int str;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-string must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &m, &n)) {
+
+      str = string_to_location(board_size, decide_this); 
+      if (str == NO_MOVE) {
 	fprintf(stderr, "gnugo: --decide-string: strange coordinate \n");
 	return EXIT_FAILURE;
       }
 
-      rotate(m, n, &m, &n, board_size, orientation);
-      decide_string(POS(m, n));
+      decide_string(str);
     }
     break;
   
   case MODE_DECIDE_CONNECTION:
     {
-      int ai, aj, bi, bj;
+      int str1, str2;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-connection must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &ai, &aj)) {
-	fprintf(stderr,
-		"usage: --decide-connection [first string]/[second string]\n");
-	return EXIT_FAILURE;
-      }
-      
-      if (!string_to_location(board_size, decide_that, &bi, &bj)) {
+
+      str1 = string_to_location(board_size, decide_this);
+      if (str1 == NO_MOVE) {
 	fprintf(stderr,
 		"usage: --decide-connection [first string]/[second string]\n");
 	return EXIT_FAILURE;
       }
 
-      rotate(ai, aj, &ai, &aj, board_size, orientation);
-      rotate(bi, bj, &bi, &bj, board_size, orientation);
-      decide_connection(POS(ai, aj), POS(bi, bj));
+      str2 = string_to_location(board_size, decide_that);
+      if (str2 == NO_MOVE) {
+	fprintf(stderr,
+		"usage: --decide-connection [first string]/[second string]\n");
+	return EXIT_FAILURE;
+      }
+
+      decide_connection(str1, str2);
     }
     break;
   
   case MODE_DECIDE_OWL:
     {
-      int m, n;
+      int pos;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-dragon must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &m, &n)) {
+
+      pos = string_to_location(board_size, decide_this);
+      if (pos == NO_MOVE) {
 	fprintf(stderr, "gnugo: --decide-dragon: strange coordinate \n");
 	return EXIT_FAILURE;
       }
 
-      rotate(m, n, &m, &n, board_size, orientation);
-      decide_owl(POS(m, n));
+      decide_owl(pos);
     }
     break;
   
   case MODE_DECIDE_DRAGON_DATA:
     {
-      int m, n;
+      int pos;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-dragon-data must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &m, &n)) {
+
+      pos = string_to_location(board_size, decide_this);
+      if (pos == NO_MOVE) {
 	fprintf(stderr, "gnugo: --decide-dragon-data: strange coordinate \n");
 	return EXIT_FAILURE;
       }
 
-      rotate(m, n, &m, &n, board_size, orientation);
-      decide_dragon_data(POS(m, n));
+      decide_dragon_data(pos);
     }
     break;
   
   case MODE_DECIDE_SEMEAI:
     {
-      int ai, aj, bi, bj;
+      int pos1, pos2;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-semeai must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &ai, &aj)) {
-	fprintf(stderr, 
-		"usage: --decide-semeai [first dragon]/[second dragon]\n");
-	return EXIT_FAILURE;
-      }
-      
-      if (!string_to_location(board_size, decide_that, &bi, &bj)) {
+
+      pos1 = string_to_location(board_size, decide_this);
+      if (pos1 == NO_MOVE) {
 	fprintf(stderr, 
 		"usage: --decide-semeai [first dragon]/[second dragon]\n");
 	return EXIT_FAILURE;
       }
 
-      rotate(ai, aj, &ai, &aj, board_size, orientation);
-      rotate(bi, bj, &bi, &bj, board_size, orientation);
-      decide_semeai(POS(ai, aj), POS(bi, bj));
+      pos2 = string_to_location(board_size, decide_that);
+      if (pos2 == NO_MOVE) {
+	fprintf(stderr, 
+		"usage: --decide-semeai [first dragon]/[second dragon]\n");
+	return EXIT_FAILURE;
+      }
+
+      decide_semeai(pos1, pos2);
     }
     break;
     
 
   case MODE_DECIDE_TACTICAL_SEMEAI:
     {
-      int ai, aj, bi, bj;
+      int pos1, pos2;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-tactical-semeai must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &ai, &aj)) {
-	fprintf(stderr, 
-		"usage: --decide-tactical-semeai [first dragon]/[second dragon]\n");
-	return EXIT_FAILURE;
-      }
-      
-      if (!string_to_location(board_size, decide_that, &bi, &bj)) {
+
+      pos1 = string_to_location(board_size, decide_this);
+      if (pos1 == NO_MOVE) {
 	fprintf(stderr, 
 		"usage: --decide-tactical-semeai [first dragon]/[second dragon]\n");
 	return EXIT_FAILURE;
       }
 
-      rotate(ai, aj, &ai, &aj, board_size, orientation);
-      rotate(bi, bj, &bi, &bj, board_size, orientation);
-      decide_tactical_semeai(POS(ai, aj), POS(bi, bj));
+      pos2 = string_to_location(board_size, decide_that);
+      if (pos2 == NO_MOVE) {
+	fprintf(stderr, 
+		"usage: --decide-tactical-semeai [first dragon]/[second dragon]\n");
+	return EXIT_FAILURE;
+      }
+
+      decide_tactical_semeai(pos1, pos2);
     }
     break;
     
@@ -1295,20 +1228,20 @@ main(int argc, char *argv[])
     
   case MODE_DECIDE_EYE:
     {
-      int m, n;
+      int pos;
       
       if (!infilename) {
 	fprintf(stderr, "gnugo: --decide-eye must be used with -l\n");
 	return EXIT_FAILURE;
       }
-      
-      if (!string_to_location(board_size, decide_this, &m, &n)) {
+
+      pos = string_to_location(board_size, decide_this);
+      if (pos == NO_MOVE) {
 	fprintf(stderr, "gnugo: --decide-eye: strange coordinate \n");
 	return EXIT_FAILURE;
       }
       
-      rotate(m, n, &m, &n, board_size, orientation);
-      decide_eye(POS(m, n));
+      decide_eye(pos);
     }
     break;
   
@@ -1328,16 +1261,15 @@ main(int argc, char *argv[])
     
   case MODE_DECIDE_SURROUNDED:
     {
-      int m, n;
+      int pos = string_to_location(board_size, decide_this);
 
-      if (!string_to_location(board_size, decide_this, &m, &n)) {
+      if (pos == NO_MOVE) {
 	fprintf(stderr, 
 		"usage: --decide-surrounded [pos]\n");
 	return EXIT_FAILURE;
       }
 
-      rotate(m, n, &m, &n, board_size, orientation);
-      decide_surrounded(POS(m, n));
+      decide_surrounded(pos);
       break;
     }
 
@@ -1614,9 +1546,6 @@ Options providing detailed reading results etc.:\n\
    --decide-eye <string>        evaluate the eye\n\
    --decide-combination         search for combination attack (try with -o)\n\
    --genmove <color>            generate a move for color\n\
-Other options:\n\
-   --attack-by-pattern          use pattern-based tactical reading for attack\n\
-   --defend-by-pattern          use pattern-based tactical reading for defense\n\
 "
 
 #define DEBUG_FLAGS "\
