@@ -351,7 +351,7 @@ enum commands {INVALID = -1, END, EXIT, QUIT, RESIGN,
                CMD_CAPTURE, CMD_DEFEND,
                CMD_HELPDEBUG, CMD_SHOWAREA, CMD_SHOWMOYO, CMD_SHOWTERRI,
                CMD_GOTO, CMD_SAVE, CMD_LOAD, CMD_SHOWDRAGONS, CMD_LISTDRAGONS,
-	       SETHURRY, SETLEVEL, NEW, COUNT, CONTINUE
+	       SETLEVEL, NEW, COUNT, CONTINUE
 };
 
 
@@ -400,7 +400,6 @@ get_command(char *command)
   if (!strncmp(command, "play", 4)) return PLAY;
   if (!strncmp(command, "info", 4)) return INFO;
   if (!strncmp(command, "force", 4)) return FORCE;
-  if (!strncmp(command, "hurry", 5)) return SETHURRY;
   if (!strncmp(command, "level", 5)) return SETLEVEL;
   if (!strncmp(command, "pass", 4)) return PASS;
   if (!strncmp(command, "save", 3)) return CMD_SAVE;
@@ -444,7 +443,7 @@ init_sgf(Gameinfo *ginfo)
       		   level, chinese_rules);
   sgfOverwritePropertyInt(sgftree.root, "HA", ginfo->handicap);
   if (ginfo->handicap > 0)
-    gnugo_recordboard(sgftree.root);
+    sgffile_recordboard(sgftree.root);
 }
 
 
@@ -506,24 +505,24 @@ computer_move(Gameinfo *gameinfo, int *passes)
 static int
 do_move(Gameinfo *gameinfo, char *command, int *passes, int force)
 {
-  int i, j;
+  int move = string_to_location(board_size, command);
 
-  if (!string_to_location(board_size, command, &i, &j)) {
+  if (move == NO_MOVE) {
     printf("\nInvalid move: %s\n", command);
     return 0;
   }
   
-  if (!gnugo_is_legal(i, j, gameinfo->to_move)) {
+  if (!is_legal(move, gameinfo->to_move)) {
     printf("\nIllegal move: %s", command);
     return 0;
   }
 
   *passes = 0;
-  TRACE("\nyour move: %m\n\n", i, j);
+  TRACE("\nyour move: %1m\n\n", move);
   init_sgf(gameinfo);
-  gnugo_play_move(i, j, gameinfo->to_move);
+  gnugo_play_move(I(move), J(move), gameinfo->to_move);
   sgffile_add_debuginfo(sgftree.lastnode, 0.0);
-  sgftreeAddPlay(&sgftree, gameinfo->to_move, i, j);
+  sgftreeAddPlay(&sgftree, gameinfo->to_move, I(move), J(move));
   sgffile_output(&sgftree);
   
   if (opt_showboard) {
@@ -592,7 +591,7 @@ play_ascii(SGFTree *tree, Gameinfo *gameinfo, char *filename, char *until)
     if (gameinfo->handicap == 0)
       gameinfo->to_move = BLACK;
     else {
-      gameinfo->handicap = gnugo_placehand(gameinfo->handicap);
+      gameinfo->handicap = place_fixed_handicap(gameinfo->handicap);
       gameinfo->to_move = WHITE;
     }
     sgf_initialized = 0;
@@ -610,7 +609,6 @@ void
 do_play_ascii(Gameinfo *gameinfo)
 {
   int m, num;
-  int sz;
   float fnum;
   int passes = 0;  /* two passes and its over */
   int tmp;
@@ -705,12 +703,12 @@ do_play_ascii(Gameinfo *gameinfo)
 	    printf("\nInvalid board size: %d\n", num);
 	    break;
 	  }
-	  sz = num;
 	  /* Init board. */
-	  gnugo_clear_board(sz);
+	  board_size = num;
+	  clear_board();
 	  /* In case max handicap changes on smaller board. */
-	  gameinfo->handicap = gnugo_placehand(gameinfo->handicap);
-	  sgfOverwritePropertyInt(sgftree.root, "SZ", sz);
+	  gameinfo->handicap = place_fixed_handicap(gameinfo->handicap);
+	  sgfOverwritePropertyInt(sgftree.root, "SZ", board_size);
 	  sgfOverwritePropertyInt(sgftree.root, "HA", gameinfo->handicap);
 	  break;
 
@@ -729,10 +727,10 @@ do_play_ascii(Gameinfo *gameinfo)
 	    break;
 	  }
 	  /* Init board. */
-	  gnugo_clear_board(board_size);
+	  clear_board();
 	  /* Place stones on board but don't record sgf 
 	   * in case we change more info. */
-	  gameinfo->handicap = gnugo_placehand(num);
+	  gameinfo->handicap = place_fixed_handicap(num);
 	  printf("\nSet handicap to %d\n", gameinfo->handicap);
           gameinfo->to_move = (gameinfo->handicap ? WHITE : BLACK);
 	  break;
@@ -781,19 +779,6 @@ do_play_ascii(Gameinfo *gameinfo)
 	  printf("\nSet level to %d\n", level);
 	  break;
 
-	  /* Level replaces hurry as of 2.7.204. This option is retained
-	   * for compatibility with gnugoclient. 
-	   */
-	case SETHURRY:
-	  command += 6;
-	  if (sscanf(command, "%d", &num) != 1) {
-	    printf("\nInvalid command syntax!\n");
-	    break;
-	  }
-	  level = 10 - num;
-	  printf("\nSet hurry to %d\n", 10 - level);
-	  break;
-
 	case DISPLAY:
 	  if (!opt_showboard)
 	    ascii_showboard();
@@ -866,7 +851,7 @@ do_play_ascii(Gameinfo *gameinfo)
 
 	case UNDO:
 	case CMD_BACK:
-	  if (gnugo_undo_move(1)) {
+	  if (undo_move(1)) {
             sgftreeAddComment(&sgftree, "undone");
 	    sgftreeBack(&sgftree);
 	    gameinfo->to_move = OTHER_COLOR(gameinfo->to_move);
@@ -1031,7 +1016,7 @@ ascii_endgame(Gameinfo *gameinfo, int reason)
   int state = 0;
 
   if (reason == 0) {		/* Two passes, game is over. */
-    gnugo_who_wins(gameinfo->computer_player, stdout);
+    who_wins(gameinfo->computer_player, stdout);
     printf("\nIf you disagree, we may count the game together.\n");
 
     sgftreeWriteResult(&sgftree, (white_score + black_score)/2.0, 1);
@@ -1110,7 +1095,7 @@ ascii_count(Gameinfo *gameinfo)
 {
   char line[12];
   int done = 0;
-  int i, j;
+  int i;
   int xyzzy = 1;
   
   printf("\nGame over. Let's count!.\n");  
@@ -1155,58 +1140,62 @@ ascii_count(Gameinfo *gameinfo)
       ascii_showboard();
     }
     else {
-      if (!string_to_location(board_size, line, &i, &j)
-	  || BOARD(i, j) == EMPTY)
+      int pos = string_to_location(board_size, line);
+      if (pos == NO_MOVE || board[pos] == EMPTY)
 	printf("\ninvalid!\n");
       else {
-	int status = dragon_status(POS(i, j));
+	int status = dragon_status(pos);
 	status = (status == DEAD) ? ALIVE : DEAD;
-	change_dragon_status(POS(i, j), status);
+	change_dragon_status(pos, status);
 	ascii_showboard();
       }
     }
   }
-  gnugo_who_wins(gameinfo->computer_player, stdout);
+  who_wins(gameinfo->computer_player, stdout);
 }
 
 
 static void
 showcapture(char *line)
 {
-  int i, j, x, y;
-  if (line)
-    if (!string_to_location(board_size, line, &i, &j)
-	|| BOARD(i, j) == EMPTY) {
-      printf("\ninvalid point!\n");
-      return;
-    }
+  int str;
+  int move;
+
+  gg_assert(line);
+  str = string_to_location(board_size, line);
+  if (str == NO_MOVE || board[str] == EMPTY) {
+    printf("\ninvalid point!\n");
+    return;
+  }
   
-  if (gnugo_attack(i, j, &x, &y))
-    mprintf("\nSuccessfull attack of %m at %m\n", i, j, x, y);
+  if (attack(str, &move))
+    mprintf("\nSuccessful attack of %1m at %1m\n", str, move);
   else
-    mprintf("\n%m cannot be attacked\n", i, j);
+    mprintf("\n%1m cannot be attacked\n", str);
 }
 
 
 static void
 showdefense(char *line)
 {
-  int i, j, x, y;
-  if (line)
-    if (!string_to_location(board_size, line, &i, &j)
-	|| BOARD(i, j) == EMPTY) {
-      printf("\ninvalid point!\n");
-      return;
-    }
+  int str;
+  int move;
+  
+  gg_assert(line);
+  str = string_to_location(board_size, line);
+  if (str == NO_MOVE || board[str] == EMPTY) {
+    printf("\ninvalid point!\n");
+    return;
+  }
 
-    if (gnugo_attack(i, j, &x, &y)) {
-      if (gnugo_find_defense(i, j, &x, &y))
-        mprintf("\nSuccessfull defense of %m at %m\n", i, j, x, y);
+  if (attack(str, NULL)) {
+      if (find_defense(str, &move))
+        mprintf("\nSuccessful defense of %1m at %1m\n", str, move);
       else
-        mprintf("\n%m cannot be defended\n", i, j);
+        mprintf("\n%1m cannot be defended\n", str);
     }
     else
-      mprintf("\nThere is no need to defend %m\n", i, j);
+      mprintf("\nThere is no need to defend %1m\n", str);
 }
 
 
@@ -1235,7 +1224,6 @@ ascii_free_handicap(Gameinfo *gameinfo, char *handicap)
   int i;
   char line[80];
   int stones[MAX_BOARD*MAX_BOARD];
-  int x, y, pos;
 
   if (sscanf(handicap, "%d", &handi) == 1) {
     /* Gnu Go is to place handicap */
@@ -1244,12 +1232,12 @@ ascii_free_handicap(Gameinfo *gameinfo, char *handicap)
       return;
     }
 
-    gnugo_clear_board(board_size);
+    clear_board();
     handi = place_free_handicap(handi);
     printf("\nPlaced %d stones of free handicap.\n", handi);
   }
   else { /* User is to place handicap */
-    gnugo_clear_board(board_size);
+    clear_board();
     handi = 0;
 
     while (1) {
@@ -1275,7 +1263,7 @@ ascii_free_handicap(Gameinfo *gameinfo, char *handicap)
 	}
       }
       else if (!strncmp(line, "clear", 5)) {
-        gnugo_clear_board(board_size);
+        clear_board();
         handi = 0;
       }
       else if (!strncmp(line, "done", 4)) {
@@ -1285,17 +1273,19 @@ ascii_free_handicap(Gameinfo *gameinfo, char *handicap)
 	else
 	  break;
       }
-      else if (string_to_location(board_size, line, &x, &y)) {
-	pos = POS(x, y);
-	if (board[pos] != EMPTY)
-	  printf("\nThere's already a stone there.\n");
-	else {
-	  add_stone(pos, BLACK);
-	  stones[handi++] = pos;
+      else {
+	int pos = string_to_location(board_size, line);
+	if (pos != NO_MOVE) {
+	  if (board[pos] != EMPTY)
+	    printf("\nThere's already a stone there.\n");
+	  else {
+	    add_stone(pos, BLACK);
+	    stones[handi++] = pos;
+	  }
 	}
+	else
+	  printf("\nInvalid command: %s", line);
       }
-      else
-	printf("\nInvalid command: %s", line);
     }
   }
   gameinfo->handicap = handi;
