@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003 and 2004                   *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -16,7 +16,7 @@
  *                                                                   *
  * You should have received a copy of the GNU General Public         *
  * License along with this program; if not, write to the Free        *
- * Software Foundation, Inc., 59 Temple Place - Suite 330,           *
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
  * Boston, MA 02111, USA.                                            *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -24,7 +24,7 @@
 #define _DFA_H_
 
 
-#define DFA_MAX_BOARD		21
+#define DFA_MAX_BOARD		MAX_BOARD
 #define DFA_MAX_ORDER		((2 * DFA_MAX_BOARD - 1)	\
 				 * (2 * DFA_MAX_BOARD - 1))
 #define DFA_BASE		(3 * DFA_MAX_BOARD)
@@ -42,9 +42,6 @@
 /* Maximum pattern matched at one positions. */
 #define DFA_MAX_MATCHED		(8 * 24)
 
-/* Conversion macro. */
-#define EXPECTED_COLOR(player_c, position_c)	(convert[player_c][position_c])
-
 
 /* DFA spiral order. */
 extern int spiral[DFA_MAX_ORDER][8];
@@ -65,8 +62,8 @@ typedef struct attrib_rt
 /* DFA state. */
 typedef struct state_rt
 {
+  short next[4];
   short att;
-  unsigned short next[4];
 } state_rt_t;
 
 typedef struct dfa_rt
@@ -82,15 +79,6 @@ typedef struct dfa_rt
 } dfa_rt_t;
 
 
-#if 0
-/* Scan order. */
-typedef struct
-{
-  int i;
-  int j;
-} order_t;
-#endif
-
 
 #endif /* _DFA_H_ */
 
