@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003 and 2004                   *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -16,7 +16,7 @@
  *                                                                   *
  * You should have received a copy of the GNU General Public         *
  * License along with this program; if not, write to the Free        *
- * Software Foundation, Inc., 59 Temple Place - Suite 330,           *
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
  * Boston, MA 02111, USA.                                            *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -672,7 +672,12 @@ test_attack_either_move(int move, int color, int worma, int wormb)
   if (trymove(move, color, "test_attack_either_move", worma)) {
     if (board[worma] == OTHER_COLOR(color)
 	&& board[wormb] == OTHER_COLOR(color)) {
-      if (!defend_both(worma, wormb))
+      if (!find_defense(worma, NULL) || !find_defense(wormb, NULL)) {
+	if (0)
+	  gprintf("%1m: Rej. attack_either_move for %1m & %1m (regular attack)\n",
+		  move, worma, wormb);
+      }
+      else if (!defend_both(worma, wormb))
         add_either_move(move, ATTACK_STRING, worma, ATTACK_STRING, wormb);
       else {
 	if (0)
@@ -755,22 +760,22 @@ backfill_replace(int move, int str)
 int 
 thrash_around_helper(ARGS)
 {
-  int d;
   UNUSED(pattern);
   UNUSED(trans);
   UNUSED(move);
-  
+
+  /* Do not generate these moves when doing scoring or if fuseki move
+   * generation is disabled (typically used when solving life and
+   * death problems embedded on a big board).
+   */
   if (doing_scoring
+      || disable_fuseki
       || (stones_on_board(BLACK | WHITE) > board_size * board_size * 2 / 5
 	  && stones_on_board(WHITE) > board_size * board_size / 5)
-      || color == BLACK)
+      || color == BLACK
+      || lively_dragon_exists(WHITE))
     return 0;
 
-  for (d = 0; d < number_of_dragons; d++)
-    if (DRAGON(d).color == WHITE
-	&& DRAGON(d).status != DEAD)
-      return 0;
-
   return 1;
 }
 
