@@ -170,8 +170,8 @@ typedef int (*autohelper_fn_ptr)(int rotation, int move,
 
 
 typedef struct patval {
-  int offset;
-  int att;
+  short offset;
+  unsigned char att;
 } Patval;
 
 /* Build-time version of patval structure. */
@@ -275,27 +275,20 @@ struct pattern {
 };
 
 
-#if EXPERIMENTAL_READING
-struct tree_node_list;
-#endif
-
 struct pattern_db {
   int fixed_for_size;
   const int fixed_anchor;
   struct pattern *patterns;
   struct dfa_rt *pdfa;
-#if EXPERIMENTAL_READING
-  struct tree_node_list *tnl; /* For tree-based pattern matching */
-#endif
 };
 
 
 struct fullboard_pattern {
-  struct patval *patn;  /* array of elements */
-  int patlen;           /* number of elements */
-  const char *name;     /* short description of pattern (optional) */
-  int move_offset;      /* offset of the suggested move (to intersection (0,0)) */
-  float value;          /* value for pattern, if matched */
+  Hash_data fullboard_hash;	/* Hash of the full board position. */	
+  int number_of_stones;		/* Number of stones on board. */
+  const char *name;		/* Pattern identifier. */
+  int move_offset;      	/* position of the move relative to tengen */
+  int value;			/* value for pattern, if matched */
 };
 
 
@@ -334,23 +327,6 @@ void backfill_replace(int move, int str);
 int break_mirror_helper(int str, int color);
 
 
-void init_tree_conn(void);
-void init_tree_pat(void);
-void init_tree_attpat(void);
-void init_tree_defpat(void);
-void init_tree_influencepat(void);
-void init_tree_barrierspat(void);
-void init_tree_endpat(void);
-void init_tree_aa_attackpat(void);
-void init_tree_owl_attackpat(void);
-void init_tree_owl_vital_apat(void);
-void init_tree_owl_defendpat(void);
-void init_tree_fusekipat(void);
-void init_tree_joseki(void);
-void init_tree_read_attack(void);
-void init_tree_read_defend(void);
-void init_tree_oracle(void);
-
 /* pattern arrays themselves */
 extern struct pattern_db pat_db;
 extern struct pattern_db aa_attackpat_db;
@@ -373,40 +349,6 @@ extern struct fullboard_pattern fuseki19[];
 extern struct fullboard_pattern fuseki13[];
 extern struct fullboard_pattern fuseki9[];
 
-#if EXPERIMENTAL_READING
-
-/* Experimental reading */
-extern struct pattern_db read_attack_db;
-extern struct pattern_db read_defend_db;
-
-#endif
-
-/* Tree-based pattern matching structures*/
-
-struct match_node;
-struct tree_node_list;
-
-struct match_node {
-  int patnum;
-  int orientation;
-  struct match_node *next;
-};
-
-
-struct tree_node {
-  struct match_node *matches;
-  int att;
-  int x;
-  int y;
-  struct tree_node_list *next_list;
-};
-
-struct tree_node_list {
-  struct tree_node node;
-  struct tree_node_list *next;
-};
-
-
 struct corner_db;
 struct corner_variation;
 struct corner_pattern;
@@ -415,18 +357,18 @@ struct corner_db {
   int max_width;	/* Largest possible width and... */
   int max_height;	/* ... largest possible height of database patterns. */
 
-  char num_top_variations; /* Number of top level variations. */
+  unsigned char num_top_variations; /* Number of top level variations. */
   struct corner_variation *top_variations;
 };
 
 struct corner_variation {
-  int move_offset;	/* Offset of the move in this variation. */
-  char xor_att; 	/* 0 - the same color as the first matched stone,
-			 * 3 - the opposite color.
-			 */
-  char num_stones;      /* Number of stones in the `move_offset' rectangle. */
+  int move_offset;	    /* Offset of the move in this variation. */
+  signed char xor_att;      /* 0 - the same color as the first matched stone,
+			     * 3 - the opposite color.
+			     */
+  unsigned char num_stones; /* Number of stones in the `move_offset' rectangle. */
 
-  char num_variations;  /* Number of subvariations. */
+  unsigned char num_variations; /* Number of subvariations. */
   struct corner_variation *variations; /* Pointer to subvariation array. */
 
   struct corner_pattern *pattern; /* Address of matched pattern (if any). */
@@ -449,10 +391,10 @@ struct corner_pattern {
 /* Build time version of corner_variation structure. */
 struct corner_variation_b {
   int move_offset;
-  char xor_att;
-  char num_stones;
+  signed char xor_att;
+  unsigned char num_stones;
 
-  char num_variations;
+  unsigned char num_variations;
   struct corner_variation_b *next;
   struct corner_variation_b *child;
   int child_num;
